############
EnergySystem
############

.. Enable manual line breaks in parameter descriptions

.. |br| raw:: html

   <br />

.. automodule:: aristopy.energySystem

.. autoclass:: EnergySystem
   :members:
   :undoc-members: